/*
   author:  Rony G. Flatscher
   date:    2006-06-25
   changed: ---

   version: 1.0.0
   name:    add_ooRexxPackage.rex
   purpose: adds package "ScriptProviderForooRexx.jar" for all OOo users ("shared" context)
   needs:   UNO.CLS

   license:

    ------------------------ Apache Version 2.0 license -------------------------
       Copyright (C) 2006 Rony G. Flatscher

       Licensed under the Apache License, Version 2.0 (the "License");
       you may not use this file except in compliance with the License.
       You may obtain a copy of the License at

           http://www.apache.org/licenses/LICENSE-2.0

       Unless required by applicable law or agreed to in writing, software
       distributed under the License is distributed on an "AS IS" BASIS,
       WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
       See the License for the specific language governing permissions and
       limitations under the License.
    -----------------------------------------------------------------------------
*/

/*
   rexx add_ooRexxPackage > {/dev/null|nul}

   LInux:   "/dev/null"
   Windows: "nul"

*/

bInstall=(arg()=0)      -- install, if no argument given, otherwise de-install only

   /* initialize connection to server, get XContext */
xContext    = UNO.connect()  -- connect to server and retrieve the XContext object
XMcf        = xContext~getServiceManager   -- retrieve XMultiComponentFactory

packageName = "ScriptProviderForooRexx.jar"
mediaType   = "application/vnd.sun.star.uno-component;type=Java"

tmpName     = stream(packageName, "C", "QUERY EXISTS")   -- get fully qualified filename
if tmpName  = "" then
do
   .error~say("Cannot find" pp(packageName)", aborting...")
   exit -1
end
urlName     = ConvertToUrl(tmpName) -- turn into ucp compliant URL

   -- get the pre-registered package manager factory singleton object
pmName="/singletons/com.sun.star.deployment.thePackageManagerFactory"
xpmf=xContext~getValueByName(pmName)~XPackageManagerFactory

   -- make sure package is removed from "user" context
call removePackage xpmf~getPackageManager("user"), packageName

   -- work on "shared" (global) package context
xpmShared=xpmf~getPackageManager("shared")   -- get "shared" package manager
call removePackage xpmShared, packageName             -- remove old package

if bInstall then  -- install package ?
do
   xpmShared~addPackage(urlName, mediaType, .nil, .nil)  -- add package

   dp=getDeployedPackage(xpmShared, packageName)         -- query package
   if .nil<>dp then  -- package object available?
      say "Is ["packageName"] registered?" "["dp~isRegistered(.nil,.nil)~value~value"]"
   else
      say "["packageName"] could not be added!"
end



::requires UNO.CLS    -- get UNO support for ooRexx

::routine removePackage       -- remove a given package
  use arg xpmf, packageName

  signal on any      -- activate execption handling
  xpmf~removePackage(packageName, .nil, .nil)

  any: return        -- just return

::routine getDeployedPackage  -- get and return the deployed package object
  use arg xpm, packageName

  signal on any      -- activate exception handling
  return xpm~getDeployedPackage(packageName, .nil)

  any: return .nil   -- exception occurred return .nil

